# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).
<!-- markdownlint-disable MD024 -->

## [rf24ble-rs/0.1.4] - 2025-07-22

### <!-- 6 --> 📦 Dependency updates

- Migrate to napi-rs v3 by @2bndy5 in [#64](https://github.com/nRF24/rf24-rs/pull/64)
- Bump `rf24-rs` to v0.3.1 by @2bndy5 in [`70bdf19`](https://github.com/nRF24/rf24-rs/commit/70bdf197249712bab51fb59b34397598ba2fa86f)
- Bump `rf24ble-rs` to v0.1.4 by @2bndy5 in [`0ff3ffa`](https://github.com/nRF24/rf24-rs/commit/0ff3ffa3b96c19cf63537603260a468cc1d8d286)

### <!-- 8 --> 📝 Documentation

- Use typedoc default HTML output by @2bndy5 in [#59](https://github.com/nRF24/rf24-rs/pull/59)

[rf24ble-rs/0.1.4]: https://github.com/nRF24/rf24-rs/compare/rf24ble-rs/0.1.3...rf24ble-rs/0.1.4

Full commit diff: [`rf24ble-rs/0.1.3...rf24ble-rs/0.1.4`][rf24ble-rs/0.1.4]

## [rf24ble-rs/0.1.3] - 2025-05-04

### <!-- 1 --> 🚀 Added

- Use concrete error type by @2bndy5 in [#42](https://github.com/nRF24/rf24-rs/pull/42)

### <!-- 6 --> 📦 Dependency updates

- Bump `rf24-rs` to v0.3.0 by @2bndy5 in [`abb8fda`](https://github.com/nRF24/rf24-rs/commit/abb8fdab9575ef30fa3445067aca11f21f07dfbb)
- Bump `rf24ble-rs` to v0.1.3 by @2bndy5 in [`d408ffe`](https://github.com/nRF24/rf24-rs/commit/d408ffeee12c94b6580e7114bc9d6ab3a7eeeb23)

[rf24ble-rs/0.1.3]: https://github.com/nRF24/rf24-rs/compare/rf24ble-rs/0.1.2...rf24ble-rs/0.1.3

Full commit diff: [`rf24ble-rs/0.1.2...rf24ble-rs/0.1.3`][rf24ble-rs/0.1.3]

## [rf24ble-rs/0.1.2] - 2025-04-08

### <!-- 6 --> 📦 Dependency updates

- Update defmt requirement from 0.3.10 to 1.0.1 in the cargo group by @dependabot[bot] in [#31](https://github.com/nRF24/rf24-rs/pull/31)
- Bump `rf24ble-rs` to v0.1.2 by @2bndy5 in [`33fe013`](https://github.com/nRF24/rf24-rs/commit/33fe0130101feb42aaa49aa5b88ac928034ec261)

### <!-- 9 --> 🗨️ Changed

- Regenerate change logs by @2bndy5 in [`581751a`](https://github.com/nRF24/rf24-rs/commit/581751af27d074797b4749572f05e9f8b3548e21)

[rf24ble-rs/0.1.2]: https://github.com/nRF24/rf24-rs/compare/rf24ble-rs/0.1.1...rf24ble-rs/0.1.2

Full commit diff: [`rf24ble-rs/0.1.1...rf24ble-rs/0.1.2`][rf24ble-rs/0.1.2]

## [rf24ble-rs/0.1.1] - 2025-04-06

### <!-- 4 --> 🛠️ Fixed

- Use const for max BLE payload size by @2bndy5 in [#30](https://github.com/nRF24/rf24-rs/pull/30)

### <!-- 6 --> 📦 Dependency updates

- Bump `rf24ble-rs` to v0.1.1 by @2bndy5 in [`3094968`](https://github.com/nRF24/rf24-rs/commit/3094968d17f63dea1594b0438534319f3aac5e89)

[rf24ble-rs/0.1.1]: https://github.com/nRF24/rf24-rs/compare/rf24ble-rs/0.1.0...rf24ble-rs/0.1.1

Full commit diff: [`rf24ble-rs/0.1.0...rf24ble-rs/0.1.1`][rf24ble-rs/0.1.1]

## [rf24ble-rs/0.1.0] - 2025-04-06

### <!-- 1 --> 🚀 Added

- Add fake BLE API for nRF24L01 by @2bndy5 in [#25](https://github.com/nRF24/rf24-rs/pull/25)

### <!-- 6 --> 📦 Dependency updates

- Bump `rf24-rs` to v0.2.1 by @2bndy5 in [`f266b96`](https://github.com/nRF24/rf24-rs/commit/f266b9695f1c492cce1ea7720a6df4fde298c338)
- Bump `rf24ble-rs` to v0.1.0 by @2bndy5 in [`1513ada`](https://github.com/nRF24/rf24-rs/commit/1513ada7aa678588ef153cbe1511021efeb7b286)

[rf24ble-rs/0.1.0]: https://github.com/nRF24/rf24-rs/compare/f8863cc36d66708bfa0fb2fb1a219c7b2f97f7d6...rf24ble-rs/0.1.0

Full commit diff: [`f8863cc...rf24ble-rs/0.1.0`][rf24ble-rs/0.1.0]

<!-- generated by git-cliff -->
